@@ -1,18 +1,14 @@
 from __future__ import annotations
 
-from mkdocs.config import Config
-from mkdocs.structure.files import File
-from mkdocs.structure.nav import Link, Section
+from mkdocs.structure.nav import Section
 from mkdocs.structure.pages import Page
 
-__version__ = "0.3.5"
+__version__ = "0.3.8"
 __all__ = ["SectionPage"]
 
 
 class SectionPage(Section, Page):  # type: ignore[misc]
-    def __init__(
-        self, title: str, file: File, config: Config, children: list[Page | Section | Link]
-    ):
+    def __init__(self, title: str, file, config, children):
         Page.__init__(self, title=title, file=file, config=config)
         Section.__init__(self, title=title, children=children)
         self.is_section = self.is_page = True
@@ -20,7 +16,10 @@ class SectionPage(Section, Page):  # type: ignore[misc]
     active = Page.active  # type: ignore
 
     def __repr__(self):
-        return "Section" + Page.__repr__(self)
+        result = Page.__repr__(self)
+        if not result.startswith("Section"):
+            result = "Section" + result
+        return result
 
     def __eq__(self, other):
         return object.__eq__(self, other)
