@@ -30,12 +30,25 @@ class TemplateRewritingLoader(BaseLoader):
         if path.endswith("/mkdocs/templates/sitemap.xml"):
             src = _transform_mkdocs_sitemap_template(src)
         else:
-            if path.endswith("/material/partials/nav-item.html"):
+            # the second path is used in MkDocs-Material >= 9.4
+            if path.endswith(
+                (
+                    "/material/partials/nav-item.html",
+                    "/material/templates/partials/nav-item.html",
+                ),
+            ):
                 src = _transform_material_nav_item_template(src)
-            elif path.endswith("/material/partials/tabs-item.html"):
+            elif path.endswith(
+                (
+                    "/material/partials/tabs-item.html",
+                    "/material/templates/partials/tabs-item.html",
+                ),
+            ):
                 src = _transform_material_tabs_item_template(src)
             elif path.endswith("/themes/readthedocs/base.html"):
                 src = _transform_readthedocs_base_template(src)
+            elif path.endswith("/nature/base.html"):
+                src = None  # Just works!
             else:
                 return src, filename, uptodate
             self.found_supported_theme = True
@@ -92,6 +105,8 @@ def _transform_material_nav_item_template(src: str) -> str:
 
 
 def _transform_material_tabs_item_template(src: str) -> str:
+    src = src.replace("{% if first.children %}", "{% if first.children and not first.url %}")
+    # The above only for versions >= 9.2
     src = src.replace(
         "{% if nav_item.children %}", "{% if nav_item.children and not nav_item.url %}"
     )
